@@ -1,7 +1,4 @@
-import csv
 import os
-import time
-import json
 
 from cvdastwrapper.runconfig import dlogrespdname
 
@@ -29,18 +26,10 @@ def generate_test_report(api_test_report, spec, test):
     api_test_report[spec]['total_failed_count'] += len(failed_test)
     spec_report = api_test_report[spec]
 
-    known_api = set()
-    sr_no = 0
-
     # parse failed resport
     for each_failed_test in failed_test:
         api = each_failed_test.get('api', '')
         # method = each_failed_test.get('method', '')
-        if api not in known_api:
-            known_api.add(api)
-            sr_no = 0
-        sr_no += 1
-
         attack = each_failed_test.get('attack', '')
         severity = each_failed_test.get('severity', '')
         attack_info = each_failed_test.get('attackinfo', {})
@@ -123,11 +112,16 @@ def generate_test_report(api_test_report, spec, test):
             status_code = response_split[0].strip()
             response = response_split[1].strip()
 
-        req_resp_file_name = dlogrespdname + '/request_response_'+ api.replace('/', '-') + '.csv'
-        with open(req_resp_file_name, 'a+') as csvfile:
-            csvwriter = csv.writer(csvfile, delimiter='|', lineterminator='\n')
-            csvwriter.writerow([sr_no, testinput.strip(), status_code, response])
-        api_details[attack]['testinput'] = '<a href=\'' + req_resp_file_name + '\'>Request_Response</a>'
+        req_resp_file_name = dlogrespdname + '/request_response_'+ api.replace('/', '-') + '.html'
+        if not os.path.exists(req_resp_file_name):
+            with open(req_resp_file_name, 'w') as iofile:
+                iofile.write('<style> * { font-family: "Roboto", sans-serif; font-weight: 400; line-height: 1.5em;}'
+                             ' b { font-weight: 700;}</style>')
+        with open(req_resp_file_name, 'a+') as iofile:
+            iofile.write('<b>Request:</b> ' + testinput.strip() + '<br>')
+            iofile.write('<b>Status Code:</b> ' + status_code + '<br>')
+            iofile.write('<b>Response:</b> ' + response + '<br><hr>')
+        api_details[attack]['testinput'] = '<a href=\'' + req_resp_file_name + '\' target="_blank">Open Test Result</a>'
 
         if api in spec_report:
             spec_report[api].update(api_details)
